
///////////////////////////////////////////////////////////////////////////
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the version 3 of the GNU General Public License //
// as published by the Free Software Foundation.                         //
//                                                                       //
// This program is distributed in the hope that it will be useful, but   //
// WITHOUT ANY WARRANTY; without even the implied warranty of            //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      //
// General Public License for more details.                              //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program. If not, see <http://www.gnu.org/licenses/>.  //
//                                                                       //
// Written by Francois Fleuret, (C) IDIAP                                //
// Contact <francois.fleuret@idiap.ch> for comments & bug reports        //
///////////////////////////////////////////////////////////////////////////

#include "image.h"

Image::Image(int width, int height) {
  _width = width;
  _height = height;
  _content = new unsigned char[_width * _height];
}

Image::Image() {
  _width = 0;
  _height = 0;
  _content = 0;
}

Image::~Image() {
  delete[] _content;
}

void Image::crop(int xmin, int ymin, int width, int height) {
  ASSERT(xmin >= 0 && xmin + width <= _width &&
         ymin >= 0 && ymin + height <= _height);
  unsigned char *new_content = new unsigned char[width * height];
  for(int y = 0; y < height; y++) {
    for(int x = 0; x < width; x++) {
      new_content[x + (y * width)] = _content[x + xmin + _width * (y + ymin)];
    }
  }
  delete[] _content;
  _content = new_content;
  _width = width;
  _height = height;
}

void Image::to_rgb(RGBImage *image) {
  int c;
  for(int y = 0; y < _height; y++) {
    for(int x = 0; x < _width; x++) {
      c = value(x, y);
      image->set_pixel(x, y, c, c, c);
    }
  }
}

void Image::read(istream *in) {
  delete[] _content;
  read_var(in, &_width);
  read_var(in, &_height);
  _content = new unsigned char[_width * _height];
  in->read((char *) _content, sizeof(unsigned char) * _width * _height);
}

void Image::write(ostream *out) {
  write_var(out, &_width);
  write_var(out, &_height);
  out->write((char *) _content, sizeof(unsigned char) * _width * _height);
}
